==> qtjambi-designer-debuginfo-macos-5.15.20.jar: sources/QtJambiDesigner/QDesignerLanguageExtension_shell.h <==
#ifndef QDESIGNERLANGUAGEEXTENSION_IMPL_SHELL_H
#define QDESIGNERLANGUAGEEXTENSION_IMPL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtDesigner/abstractlanguage.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QVariant>
#include <QtCore/qobject.h>
#include <QtCore/qstring.h>
#include <QtDesigner/abstractformeditor.h>
#include <QtDesigner/abstractformwindow.h>
#include <QtDesigner/abstractresourcebrowser.h>
#include <qtwidgets-config.h>
#if QT_CONFIG(dialog)
#include <QtWidgets/qdialog.h>
#endif //QT_CONFIG(dialog)
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


class QDesignerLanguageExtension_shell : public QDesignerLanguageExtension, public QtJambiShellInterface
{
public:
    QDesignerLanguageExtension_shell();
    ~QDesignerLanguageExtension_shell() override;

    QString classNameOf(QObject* object0) const override;
    QDialog* createFormWindowSettingsDialog(QDesignerFormWindowInterface* formWindow0, QWidget* parentWidget1) override;
    QDialog* createPromotionDialog(QDesignerFormEditorInterface* formEditor0, const QString& promotableWidgetClassName1, QString* promoteToClassName2, QWidget* parentWidget3) override;
    QDialog* createPromotionDialog(QDesignerFormEditorInterface* formEditor0, QWidget* parentWidget1) override;
    QDesignerResourceBrowserInterface* createResourceBrowser(QWidget* parentWidget0) override;
    bool isLanguageResource(const QString& path0) const override;
    QString name() const override;
    bool signalMatchesSlot(const QString& signal0, const QString& slot1) const override;
    QString uiExtension() const override;
    QString widgetBoxContents() const override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDesignerLanguageExtension_access : public QDesignerLanguageExtension
{
    jstring __qt_classNameOf_QObject_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID object0) const;
    jobject __qt_createFormWindowSettingsDialog_QDesignerFormWindowInterface_ptr_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID formWindow0, QtJambiNativeID parentWidget1);
    jobject __qt_createPromotionDialog_QDesignerFormEditorInterface_ptr_cref_QString_QString_ptr_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID formEditor0, jstring promotableWidgetClassName1, jobjectArray promoteToClassName2, QtJambiNativeID parentWidget3);
    jobject __qt_createPromotionDialog_QDesignerFormEditorInterface_ptr_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID formEditor0, QtJambiNativeID parentWidget1);
    jobject __qt_createResourceBrowser_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parentWidget0);
    jboolean __qt_isLanguageResource_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring path0) const;
    jstring __qt_name_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_signalMatchesSlot_cref_QString_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring signal0, jstring slot1) const;
    jstring __qt_uiExtension_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_widgetBoxContents_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QDESIGNERLANGUAGEEXTENSION_IMPL_SHELL_H

==> qtjambi-designer-debuginfo-macos-6.5.4.jar: sources/QtJambiDesigner/QDesignerLanguageExtension_shell.h <==
#ifndef QDESIGNERLANGUAGEEXTENSION_IMPL_SHELL_H
#define QDESIGNERLANGUAGEEXTENSION_IMPL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtDesigner/abstractlanguage.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QVariant>
#include <QtCore/qobject.h>
#include <QtCore/qstring.h>
#include <QtDesigner/abstractformeditor.h>
#include <QtDesigner/abstractformwindow.h>
#include <QtDesigner/abstractresourcebrowser.h>
#include <qtwidgets-config.h>
#if QT_CONFIG(dialog)
#include <QtWidgets/qdialog.h>
#endif //QT_CONFIG(dialog)
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


class QDesignerLanguageExtension_shell : public QDesignerLanguageExtension, public QtJambiShellInterface
{
public:
    QDesignerLanguageExtension_shell();
    ~QDesignerLanguageExtension_shell() override;

    QString classNameOf(QObject* object0) const override;
    QDialog* createFormWindowSettingsDialog(QDesignerFormWindowInterface* formWindow0, QWidget* parentWidget1) override;
    QDialog* createPromotionDialog(QDesignerFormEditorInterface* formEditor0, const QString& promotableWidgetClassName1, QString* promoteToClassName2, QWidget* parentWidget3) override;
    QDialog* createPromotionDialog(QDesignerFormEditorInterface* formEditor0, QWidget* parentWidget1) override;
    QDesignerResourceBrowserInterface* createResourceBrowser(QWidget* parentWidget0) override;
    bool isLanguageResource(const QString& path0) const override;
    QString name() const override;
    bool signalMatchesSlot(const QString& signal0, const QString& slot1) const override;
    QString uiExtension() const override;
    QString widgetBoxContents() const override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDesignerLanguageExtension_access : public QDesignerLanguageExtension
{
    jstring __qt_classNameOf_QObject_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID object0) const;
    jobject __qt_createFormWindowSettingsDialog_QDesignerFormWindowInterface_ptr_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID formWindow0, QtJambiNativeID parentWidget1);
    jobject __qt_createPromotionDialog_QDesignerFormEditorInterface_ptr_cref_QString_QString_ptr_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID formEditor0, jstring promotableWidgetClassName1, jobjectArray promoteToClassName2, QtJambiNativeID parentWidget3);
    jobject __qt_createPromotionDialog_QDesignerFormEditorInterface_ptr_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID formEditor0, QtJambiNativeID parentWidget1);
    jobject __qt_createResourceBrowser_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parentWidget0);
    jboolean __qt_isLanguageResource_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring path0) const;
    jstring __qt_name(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_signalMatchesSlot_cref_QString_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring signal0, jstring slot1) const;
    jstring __qt_uiExtension(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_widgetBoxContents(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QDESIGNERLANGUAGEEXTENSION_IMPL_SHELL_H
